@@ -1,5 +1,5 @@
 /* version.c --- Version handling.
- * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008  Simon Josefsson
  *
  * This file is part of the Generic Security Service (GSS).
  *
@@ -22,7 +22,7 @@
 
 #include "internal.h"
 
-#include <strverscmp.h>
+#include <string.h> /* for strverscmp */
 
 /**
  * gss_check_version:
